pitchtools.MelodicObject
========================

.. abjad-lineage:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject

.. autoclass:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__repr__
   :noindex:
